==> react-hr-component-kc-1.0.17.tgz: package/src/components/OnboardOrgEnvTest.js <==
import React, { useState } from "react";
import ReactDOM from "react-dom";
import { Form, Row, Col, Button } from "react-bootstrap";

function OnboardOrgEnvTest(props) {
  const [orgEnvData, setOrgEnvData] = useState({
    orgName: "",
    credential: "",
    env: [
      {
        name: "",
      },
    ],
  });

  const addEnv = (e) => {
    let temp = { ...orgEnvData };
    temp.env.push({
      name: "",
    });
    setOrgEnvData(temp);
  };

  const deleteEnv = (e, i) => {
    let temp = { ...orgEnvData };
    temp.env.splice(i, 1);
    setOrgEnvData(temp);
  };

  //org name change
  const handleOrgNameChange = (e) => {
    let temp = { ...orgEnvData };
    temp[e.target.name] = e.target.value;
    setOrgEnvData(temp);
  };

  //credential name change
  const handleCredentialChange = (e) => {
    let temp = { ...orgEnvData };
    temp[e.target.name] = e.target.value;
    setOrgEnvData(temp);
  };

  const handleEnvNameChange = (e, i) => {
    let temp = { ...orgEnvData };
    temp.env[i][e.target.name] = e.target.value;
    setOrgEnvData(temp);
  };

  const submit = (e) => {
    console.log(orgEnvData);
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Onboard Org & Env</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/onboard-entity-deployment-info">Onboard Org & Env</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="orgName">
                          <Form.Label column sm={2}>
                            Org <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="orgName"
                              onChange={handleOrgNameChange}
                              value={orgEnvData.orgName}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="credential">
                          <Form.Label column sm={2}>
                            Credential <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="credential"
                              onChange={handleCredentialChange}
                              value={orgEnvData.credential}
                            />
                          </Col>
                        </Form.Group>

                        {orgEnvData.env.map((branch, i) => (
                          <div className="group-field-highlight-pattern-info ">
                            <Form.Group as={Row} controlId="environment">
                              <Form.Label column sm={2}>
                                Environment <span className="required">*</span>
                              </Form.Label>
                              <Col sm={10}>
                                <div className="row pattern-button">
                                  <Form.Control
                                    type="text"
                                    className="w-75"
                                    name="name"
                                    onChange={(e) => handleEnvNameChange(e, i)}
                                    value={orgEnvData.env[i].name}
                                  />
                                  <Button
                                    variant="secondary"
                                    onClick={(e) => deleteEnv(e, i)}
                                  >
                                    -Env
                                  </Button>
                                </div>
                              </Col>
                            </Form.Group>
                          </div>
                        ))}
                      </Form>
                      <Button variant="primary" onClick={addEnv}>
                        +Env
                      </Button>{" "}
                      <br />
                      <br />
                      <Button variant="primary" onClick={submit}>
                        Submit
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default OnboardOrgEnvTest;

==> react-hr-component-kc-1.0.20.tgz: package/src/components/OnboardOrgEnvTest.js <==
import React, { useState } from "react";
import ReactDOM from "react-dom";
import { Form, Row, Col, Button } from "react-bootstrap";

function OnboardOrgEnvTest(props) {
  const [orgEnvData, setOrgEnvData] = useState({
    orgName: "",
    credential: "",
    env: [
      {
        name: "",
      },
    ],
  });

  const addEnv = (e) => {
    let temp = { ...orgEnvData };
    temp.env.push({
      name: "",
    });
    setOrgEnvData(temp);
  };

  const deleteEnv = (e, i) => {
    let temp = { ...orgEnvData };
    temp.env.splice(i, 1);
    setOrgEnvData(temp);
  };

  //org name change
  const handleOrgNameChange = (e) => {
    let temp = { ...orgEnvData };
    temp[e.target.name] = e.target.value;
    setOrgEnvData(temp);
  };

  //credential name change
  const handleCredentialChange = (e) => {
    let temp = { ...orgEnvData };
    temp[e.target.name] = e.target.value;
    setOrgEnvData(temp);
  };

  const handleEnvNameChange = (e, i) => {
    let temp = { ...orgEnvData };
    temp.env[i][e.target.name] = e.target.value;
    setOrgEnvData(temp);
  };

  const submit = (e) => {
    console.log(orgEnvData);
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Onboard Org & Env</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/onboard-entity-deployment-info">Onboard Org & Env</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="orgName">
                          <Form.Label column sm={2}>
                            Org <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="orgName"
                              onChange={handleOrgNameChange}
                              value={orgEnvData.orgName}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="credential">
                          <Form.Label column sm={2}>
                            Credential <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="credential"
                              onChange={handleCredentialChange}
                              value={orgEnvData.credential}
                            />
                          </Col>
                        </Form.Group>
                        <p>Add Environments:</p>
                        {orgEnvData.env.map((branch, i) => (
                          <Form.Group as={Row} controlId="environment">
                            <div className="row org-env-button group-field-highlight-org-info">
                              <Form.Control
                                type="text"
                                className="w-75"
                                name="name"
                                onChange={(e) => handleEnvNameChange(e, i)}
                                value={orgEnvData.env[i].name}
                              />
                              <Button
                                variant="secondary"
                                onClick={(e) => deleteEnv(e, i)}
                              >
                                -Env
                              </Button>
                            </div>
                          </Form.Group>
                        ))}
                      </Form>
                      <Button variant="primary" onClick={addEnv}>
                        +Env
                      </Button>{" "}
                      <br />
                      <br />
                      <Button variant="primary" onClick={submit}>
                        Submit
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default OnboardOrgEnvTest;
